You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@hbase.apache.org by ja...@apache.org on 2019/08/21 14:52:15 UTC

[hbase] branch branch-1.3 updated: HBASE-22844 Fixed Checkstyle violations in client snapshot exceptions

This is an automated email from the ASF dual-hosted git repository.

janh pushed a commit to branch branch-1.3
in repository https://gitbox.apache.org/repos/asf/hbase.git


The following commit(s) were added to refs/heads/branch-1.3 by this push:
     new 2bb4a91  HBASE-22844 Fixed Checkstyle violations in client snapshot exceptions
2bb4a91 is described below

commit 2bb4a9159021172fd38687d908fe54bbb761bd33
Author: Jan Hentschel <ja...@ultratendency.com>
AuthorDate: Wed Aug 21 10:30:26 2019 +0200

    HBASE-22844 Fixed Checkstyle violations in client snapshot exceptions
    
    Signed-off-by: stack <st...@apache.org>
---
 .../snapshot/ClientSnapshotDescriptionUtils.java   | 36 +++++++++------
 .../hbase/snapshot/CorruptedSnapshotException.java | 19 +++++---
 .../hbase/snapshot/ExportSnapshotException.java    |  9 ++--
 .../hbase/snapshot/HBaseSnapshotException.java     | 54 +++++++++++++---------
 .../hbase/snapshot/RestoreSnapshotException.java   | 33 +++++++++----
 .../hbase/snapshot/SnapshotCreationException.java  | 34 ++++++++------
 .../snapshot/SnapshotDoesNotExistException.java    | 16 ++++---
 .../hbase/snapshot/SnapshotExistsException.java    | 23 +++++----
 .../snapshot/TablePartiallyOpenException.java      | 30 ++++++------
 .../hbase/snapshot/UnknownSnapshotException.java   | 16 ++++---
 10 files changed, 163 insertions(+), 107 deletions(-)

diff --git a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/ClientSnapshotDescriptionUtils.java b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/ClientSnapshotDescriptionUtils.java
index d439c8b..5b4ad33 100644
--- a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/ClientSnapshotDescriptionUtils.java
+++ b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/ClientSnapshotDescriptionUtils.java
@@ -16,11 +16,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.hadoop.hbase.snapshot;
 
-import org.apache.hadoop.hbase.classification.InterfaceAudience;
 import org.apache.hadoop.hbase.TableName;
+import org.apache.hadoop.hbase.classification.InterfaceAudience;
 import org.apache.hadoop.hbase.protobuf.generated.HBaseProtos;
 import org.apache.hadoop.hbase.util.Bytes;
 
@@ -29,18 +28,21 @@ import org.apache.hadoop.hbase.util.Bytes;
  * There is a corresponding class on the server side.
  */
 @InterfaceAudience.Private
-public class ClientSnapshotDescriptionUtils {
+public final class ClientSnapshotDescriptionUtils {
+  private ClientSnapshotDescriptionUtils() {
+  }
+
   /**
    * Check to make sure that the description of the snapshot requested is valid
    * @param snapshot description of the snapshot
    * @throws IllegalArgumentException if the name of the snapshot or the name of the table to
-   *           snapshot are not valid names.
+   *           snapshot are not valid names
    */
   public static void assertSnapshotRequestIsValid(HBaseProtos.SnapshotDescription snapshot)
       throws IllegalArgumentException {
     // make sure the snapshot name is valid
     TableName.isLegalTableQualifierName(Bytes.toBytes(snapshot.getName()), true);
-    if(snapshot.hasTable()) {
+    if (snapshot.hasTable()) {
       // make sure the table name is valid, this will implicitly check validity
       TableName tableName = TableName.valueOf(snapshot.getTable());
 
@@ -51,18 +53,22 @@ public class ClientSnapshotDescriptionUtils {
   }
 
   /**
-   * Returns a single line (no \n) representation of snapshot metadata.  Use this instead of
-   * {@link org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.SnapshotDescription#toString()}.  We don't replace SnapshotDescrpition's toString
-   * because it is auto-generated by protoc.
-   * @param ssd
-   * @return Single line string with a summary of the snapshot parameters
+   * Returns a single line (no \n) representation of snapshot metadata. Use this instead of
+   * {@link org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.SnapshotDescription#toString()}.
+   * We don't replace
+   * {@link org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.SnapshotDescription}'s
+   * {@code toString}, because it is auto-generated by protoc.
+   *
+   * @param snapshot description of the snapshot
+   * @return single line string with a summary of the snapshot parameters
    */
-  public static String toString(HBaseProtos.SnapshotDescription ssd) {
-    if (ssd == null) {
+  public static String toString(HBaseProtos.SnapshotDescription snapshot) {
+    if (snapshot == null) {
       return null;
     }
-    return "{ ss=" + ssd.getName() +
-           " table=" + (ssd.hasTable()?TableName.valueOf(ssd.getTable()):"") +
-           " type=" + ssd.getType() + " }";
+
+    return "{ ss=" + snapshot.getName() +
+           " table=" + (snapshot.hasTable() ? TableName.valueOf(snapshot.getTable()) : "") +
+           " type=" + snapshot.getType() + " }";
   }
 }
diff --git a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/CorruptedSnapshotException.java b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/CorruptedSnapshotException.java
index d29c89c..ccc6ced 100644
--- a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/CorruptedSnapshotException.java
+++ b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/CorruptedSnapshotException.java
@@ -23,32 +23,37 @@ import org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.SnapshotDescriptio
 
 
 /**
- * Exception thrown when the found snapshot info from the filesystem is not valid
+ * Exception thrown when the found snapshot info from the filesystem is not valid.
  */
 @SuppressWarnings("serial")
 @InterfaceAudience.Public
 @InterfaceStability.Evolving
 public class CorruptedSnapshotException extends HBaseSnapshotException {
-
   /**
+   * Snapshot was corrupt for some reason.
+   *
    * @param message message describing the exception
-   * @param e cause
+   * @param e the actual cause of the exception
    */
   public CorruptedSnapshotException(String message, Exception e) {
     super(message, e);
   }
 
   /**
-   * Snapshot was corrupt for some reason
+   * Snapshot was corrupt for some reason.
+   *
    * @param message full description of the failure
-   * @param snapshot snapshot that was expected
+   * @param snapshotDescription snapshot that was expected
+   * @deprecated since 1.3.0, will be removed in 3.0.0.
    */
   @Deprecated
-  public CorruptedSnapshotException(String message, SnapshotDescription snapshot) {
-    super(message, snapshot);
+  public CorruptedSnapshotException(String message, SnapshotDescription snapshotDescription) {
+    super(message, snapshotDescription);
   }
 
   /**
+   * Snapshot was corrupt for some reason.
+   *
    * @param message message describing the exception
    */
   public CorruptedSnapshotException(String message) {
diff --git a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/ExportSnapshotException.java b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/ExportSnapshotException.java
index 05f3556..120b251 100644
--- a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/ExportSnapshotException.java
+++ b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/ExportSnapshotException.java
@@ -27,17 +27,16 @@ import org.apache.hadoop.hbase.classification.InterfaceStability;
 @InterfaceStability.Stable
 @SuppressWarnings("serial")
 public class ExportSnapshotException extends HBaseSnapshotException {
-
   /**
-   * @param msg message describing the exception
+   * @param message message describing the exception
    */
-  public ExportSnapshotException(String msg) {
-    super(msg);
+  public ExportSnapshotException(String message) {
+    super(message);
   }
 
   /**
    * @param message message describing the exception
-   * @param e cause
+   * @param e the actual cause of the exception
    */
   public ExportSnapshotException(String message, Exception e) {
     super(message, e);
diff --git a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/RestoreSnapshotException.java b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/RestoreSnapshotException.java
index 25cd583..45450b1 100644
--- a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/RestoreSnapshotException.java
+++ b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/RestoreSnapshotException.java
@@ -15,7 +15,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.hadoop.hbase.snapshot;
 
 import org.apache.hadoop.hbase.classification.InterfaceAudience;
@@ -29,20 +28,38 @@ import org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.SnapshotDescriptio
 @InterfaceAudience.Public
 @InterfaceStability.Evolving
 public class RestoreSnapshotException extends HBaseSnapshotException {
+  /**
+   * @param message reason why restoring the snapshot fails
+   * @param snapshotDescription description of the snapshot attempted
+   * @deprecated since 1.3.0, will be removed in 3.0.0
+   */
   @Deprecated
-  public RestoreSnapshotException(String msg, SnapshotDescription desc) {
-    super(msg, desc);
+  public RestoreSnapshotException(String message, SnapshotDescription snapshotDescription) {
+    super(message, snapshotDescription);
   }
 
+  /**
+   * @param message reason why restoring the snapshot fails
+   * @param cause the root cause of the failure
+   * @param snapshotDescription description of the snapshot attempted
+   * @deprecated since 1.3.0, will be removed in 3.0.0
+   */
   @Deprecated
-  public RestoreSnapshotException(String msg, Throwable cause, SnapshotDescription desc) {
-    super(msg, cause, desc);
+  public RestoreSnapshotException(String message, Throwable cause,
+      SnapshotDescription snapshotDescription) {
+    super(message, cause, snapshotDescription);
   }
 
-  public RestoreSnapshotException(String msg) {
-    super(msg);
+  /**
+   * @param message reason why restoring the snapshot fails
+   */
+  public RestoreSnapshotException(String message) {
+    super(message);
   }
-
+  /**
+   * @param message reason why restoring the snapshot fails
+   * @param e the root cause of the failure
+   */
   public RestoreSnapshotException(String message, Exception e) {
     super(message, e);
   }
diff --git a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/TablePartiallyOpenException.java b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/TablePartiallyOpenException.java
index abeb7af..aba7d91 100644
--- a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/TablePartiallyOpenException.java
+++ b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/TablePartiallyOpenException.java
@@ -17,43 +17,47 @@
  */
 package org.apache.hadoop.hbase.snapshot;
 
+import java.io.IOException;
+
+import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.classification.InterfaceAudience;
 import org.apache.hadoop.hbase.classification.InterfaceStability;
-import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.util.Bytes;
 
-import java.io.IOException;
-
 /**
- * Thrown if a table should be online/offline but is partially open
+ * Thrown if a table should be online/offline, but is partially open.
  */
 @InterfaceAudience.Public
 @InterfaceStability.Evolving
 public class TablePartiallyOpenException extends IOException {
   private static final long serialVersionUID = 3571982660065058361L;
 
+  /**
+   * Constructs an {@code TablePartiallyOpenException} with {@code null} as its error detail
+   * message.
+   */
   public TablePartiallyOpenException() {
     super();
   }
 
   /**
-   * @param s message
+   * @param message the message describing the exception
    */
-  public TablePartiallyOpenException(String s) {
-    super(s);
+  public TablePartiallyOpenException(String message) {
+    super(message);
   }
 
   /**
-   * @param tableName Name of table that is partial open
+   * @param tableName the name of the table that is partially open
    */
   public TablePartiallyOpenException(TableName tableName) {
     this(tableName.getNameAsString());
   }
 
   /**
-    * @param tableName Name of table that is partial open
-    */
-   public TablePartiallyOpenException(byte[] tableName) {
-     this(Bytes.toString(tableName));
-   }
+   * @param tableName the name of the table that is partially open
+   */
+  public TablePartiallyOpenException(byte[] tableName) {
+    this(Bytes.toString(tableName));
+  }
 }
diff --git a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/HBaseSnapshotException.java b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/HBaseSnapshotException.java
index cd2f66f..08e26c2 100644
--- a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/HBaseSnapshotException.java
+++ b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/HBaseSnapshotException.java
@@ -17,62 +17,72 @@
  */
 package org.apache.hadoop.hbase.snapshot;
 
+import org.apache.hadoop.hbase.DoNotRetryIOException;
 import org.apache.hadoop.hbase.classification.InterfaceAudience;
 import org.apache.hadoop.hbase.classification.InterfaceStability;
 import org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.SnapshotDescription;
-import org.apache.hadoop.hbase.DoNotRetryIOException;
 
 /**
- * General exception base class for when a snapshot fails
+ * General exception base class for when a snapshot fails.
  */
 @SuppressWarnings("serial")
 @InterfaceAudience.Public
 @InterfaceStability.Evolving
 public class HBaseSnapshotException extends DoNotRetryIOException {
-
   private SnapshotDescription description;
 
   /**
    * Some exception happened for a snapshot and don't even know the snapshot that it was about
    * @param msg Full description of the failure
    */
-  public HBaseSnapshotException(String msg) {
-    super(msg);
+  public HBaseSnapshotException(String message) {
+    super(message);
   }
 
   /**
    * Exception for the given snapshot that has no previous root cause
    * @param msg reason why the snapshot failed
    * @param desc description of the snapshot that is being failed
    */
   @Deprecated
-  public HBaseSnapshotException(String msg, SnapshotDescription desc) {
-    super(msg);
-    this.description = desc;
+  public HBaseSnapshotException(String message, SnapshotDescription snapshotDescription) {
+    super(message);
+    this.description = snapshotDescription;
   }
 
   /**
    * Exception for the given snapshot due to another exception
    * @param msg reason why the snapshot failed
    * @param cause root cause of the failure
    * @param desc description of the snapshot that is being failed
    */
   @Deprecated
-  public HBaseSnapshotException(String msg, Throwable cause, SnapshotDescription desc) {
-    super(msg, cause);
-    this.description = desc;
+  public HBaseSnapshotException(String message, Throwable cause,
+      SnapshotDescription snapshotDescription) {
+    super(message, cause);
+    this.description = snapshotDescription;
   }
 
   /**
    * Exception when the description of the snapshot cannot be determined, due to some root other
-   * root cause
+   * root cause.
+   *
    * @param message description of what caused the failure
-   * @param e root cause
+   * @param e the root cause
    */
   public HBaseSnapshotException(String message, Exception e) {
     super(message, e);
   }
 
+  /**
+   * @return the description of the snapshot that is being failed
+   * @deprecated since 1.3.0, will be removed in 3.0.0
+   */
   @Deprecated
   public SnapshotDescription getSnapshotDescription() {
     return this.description;
@@ -17,62 +17,72 @@
 
   /**
-   * Some exception happened for a snapshot and don't even know the snapshot that it was about
-   * @param msg Full description of the failure
+   * Some exception happened for a snapshot and don't even know the snapshot that it was about.
+   *
+   * @param message the full description of the failure
    */
@@ -17,62 +17,72 @@
 
   /**
-   * Exception for the given snapshot that has no previous root cause
-   * @param msg reason why the snapshot failed
-   * @param desc description of the snapshot that is being failed
+   * Exception for the given snapshot that has no previous root cause.
+   *
+   * @param message the reason why the snapshot failed
+   * @param snapshotDescription the description of the snapshot that is failing
+   * @deprecated since 1.3.0, will be removed in 3.0.0
    */
   @Deprecated
@@ -17,62 +17,72 @@
 
   /**
-   * Exception for the given snapshot due to another exception
-   * @param msg reason why the snapshot failed
-   * @param cause root cause of the failure
-   * @param desc description of the snapshot that is being failed
+   * Exception for the given snapshot due to another exception.
+   *
+   * @param message the reason why the snapshot failed
+   * @param cause the root cause of the failure
+   * @param snapshotDescription the description of the snapshot that is being failed
+   * @deprecated since 1.3.0, will be removed in 3.0.0
    */
   @Deprecated
diff --git a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/SnapshotCreationException.java b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/SnapshotCreationException.java
index 324d41f..78514a5 100644
--- a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/SnapshotCreationException.java
+++ b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/SnapshotCreationException.java
@@ -29,32 +29,36 @@ import org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.SnapshotDescriptio
 @InterfaceAudience.Public
 @InterfaceStability.Evolving
 public class SnapshotCreationException extends HBaseSnapshotException {
-
   /**
    * Used internally by the RPC engine to pass the exception back to the client.
-   * @param msg error message to pass back
+   *
+   * @param message error message to pass back
    */
-  public SnapshotCreationException(String msg) {
-    super(msg);
+  public SnapshotCreationException(String message) {
+    super(message);
   }
 
   /**
    * Failure to create the specified snapshot
    * @param msg reason why the snapshot couldn't be completed
    * @param desc description of the snapshot attempted
    */
-  public SnapshotCreationException(String msg, SnapshotDescription desc) {
-    super(msg, desc);
+  public SnapshotCreationException(String message, SnapshotDescription snapshotDescription) {
+    super(message, snapshotDescription);
   }
 
   /**
    * Failure to create the specified snapshot due to an external cause
    * @param msg reason why the snapshot couldn't be completed
    * @param cause root cause of the failure
    * @param desc description of the snapshot attempted
    */
   @Deprecated
-  public SnapshotCreationException(String msg, Throwable cause, SnapshotDescription desc) {
-    super(msg, cause, desc);
+  public SnapshotCreationException(String message, Throwable cause,
+      SnapshotDescription snapshotDescription) {
+    super(message, cause, snapshotDescription);
   }
 }
@@ -29,32 +29,36 @@ import org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.SnapshotDescriptio
 
   /**
-   * Failure to create the specified snapshot
-   * @param msg reason why the snapshot couldn't be completed
-   * @param desc description of the snapshot attempted
+   * Failure to create the specified snapshot.
+   *
+   * @param message reason why the snapshot couldn't be completed
+   * @param snapshotDescription description of the snapshot attempted
    */
@@ -29,32 +29,36 @@ import org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.SnapshotDescriptio
 
   /**
-   * Failure to create the specified snapshot due to an external cause
-   * @param msg reason why the snapshot couldn't be completed
-   * @param cause root cause of the failure
-   * @param desc description of the snapshot attempted
+   * Failure to create the specified snapshot due to an external cause.
+   *
+   * @param message reason why the snapshot couldn't be completed
+   * @param cause the root cause of the failure
+   * @param snapshotDescription description of the snapshot attempted
+   * @deprecated since 1.3.0, will be removed in 3.0.0
    */
   @Deprecated
diff --git a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/SnapshotDoesNotExistException.java b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/SnapshotDoesNotExistException.java
index 6ba45bd..8aae8af 100644
--- a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/SnapshotDoesNotExistException.java
+++ b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/SnapshotDoesNotExistException.java
@@ -23,24 +23,26 @@ import org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.SnapshotDescriptio
 
 
 /**
- * Thrown when the server is looking for a snapshot but can't find the snapshot on the filesystem
+ * Thrown when the server is looking for a snapshot, but can't find the snapshot on the filesystem.
  */
 @SuppressWarnings("serial")
 @InterfaceAudience.Public
 @InterfaceStability.Evolving
 public class SnapshotDoesNotExistException extends HBaseSnapshotException {
   /**
    * @param msg full description of the failure
    */
-  public SnapshotDoesNotExistException(String msg) {
-    super(msg);
+  public SnapshotDoesNotExistException(String message) {
+    super(message);
   }
 
   /**
-   * @param desc expected snapshot to find
+   * @param snapshotDescription expected snapshot to find
+   * @deprecated since 1.3.0, will be removed in 3.0.0
    */
   @Deprecated
-  public SnapshotDoesNotExistException(SnapshotDescription desc) {
-    super("Snapshot '" + desc.getName() +"' doesn't exist on the filesystem", desc);
+  public SnapshotDoesNotExistException(SnapshotDescription snapshotDescription) {
+    super("Snapshot '" + snapshotDescription.getName() + "' doesn't exist on the filesystem",
+        snapshotDescription);
   }
 }
@@ -23,24 +23,26 @@ import org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.SnapshotDescriptio
 public class SnapshotDoesNotExistException extends HBaseSnapshotException {
   /**
-   * @param msg full description of the failure
+   * @param message the full description of the failure
    */
diff --git a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/SnapshotExistsException.java b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/SnapshotExistsException.java
index ff3cdcb..d2fdb6e 100644
--- a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/SnapshotExistsException.java
+++ b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/SnapshotExistsException.java
@@ -22,23 +22,30 @@ import org.apache.hadoop.hbase.classification.InterfaceStability;
 import org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.SnapshotDescription;
 
 /**
- * Thrown when a snapshot exists but should not
+ * Thrown when a snapshot exists, but should not.
  */
 @SuppressWarnings("serial")
 @InterfaceAudience.Public
 @InterfaceStability.Evolving
 public class SnapshotExistsException extends HBaseSnapshotException {
-  public SnapshotExistsException(String msg) {
-    super(msg);
+  /**
+   * Failure due to the snapshot already existing.
+   *
+   * @param message the full description of the failure
+   */
+  public SnapshotExistsException(String message) {
+    super(message);
   }
 
   /**
    * Failure due to the snapshot already existing
    * @param msg full description of the failure
    * @param desc snapshot that was attempted
    */
   @Deprecated
-  public SnapshotExistsException(String msg, SnapshotDescription desc) {
-    super(msg, desc);
+  public SnapshotExistsException(String message, SnapshotDescription snapshotDescription) {
+    super(message, snapshotDescription);
   }
 }
@@ -22,23 +22,30 @@ import org.apache.hadoop.hbase.classification.InterfaceStability;
 
   /**
-   * Failure due to the snapshot already existing
-   * @param msg full description of the failure
-   * @param desc snapshot that was attempted
+   * Failure due to the snapshot already existing.
+   *
+   * @param message the full description of the failure
+   * @param snapshotDescription snapshot that was attempted
+   * @deprecated since 1.3.0, will be removed in 3.0.0
    */
   @Deprecated
diff --git a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/UnknownSnapshotException.java b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/UnknownSnapshotException.java
index e4242f5..3f21bd3 100644
--- a/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/UnknownSnapshotException.java
+++ b/hbase-client/src/main/java/org/apache/hadoop/hbase/snapshot/UnknownSnapshotException.java
@@ -27,16 +27,18 @@ import org.apache.hadoop.hbase.classification.InterfaceStability;
 @InterfaceAudience.Public
 @InterfaceStability.Evolving
 public class UnknownSnapshotException extends HBaseSnapshotException {
-
   /**
    * @param msg full information about the failure
    */
-  public UnknownSnapshotException(String msg) {
-    super(msg);
+  public UnknownSnapshotException(String message) {
+    super(message);
   }
 
-  public UnknownSnapshotException(String msg, Exception  e) {
-    super(msg, e);
+  /**
+   * @param message full information about the failure
+   * @param e the actual cause of the exception
+   */
+  public UnknownSnapshotException(String message, Exception e) {
+    super(message, e);
   }
-
 }
@@ -27,16 +27,18 @@ import org.apache.hadoop.hbase.classification.InterfaceStability;
   /**
-   * @param msg full information about the failure
+   * @param message full information about the failure
    */